Name:           arb
Version:        2.7.0
Release:        2%{?dist}
Summary:        Arbitrary-precision floating point ball arithmetic

License:        GPLv2+
URL:            http://fredrikj.net/arb/
Source0:        https://github.com/fredrik-johansson/%{name}/archive/%{version}.tar.gz

BuildRequires:  flint-devel
BuildRequires:  gmp-devel
BuildRequires:  mpfr-devel
BuildRequires:  ntl-devel
BuildRequires:  python-sphinx

%global majver %(cut -d. -f1 <<< %{version})

%description
Arb is a C library for arbitrary-precision floating-point ball
arithmetic.  It supports efficient high-precision computation with
polynomials, power series, matrices and special functions over the real
and complex numbers, with automatic, rigorous error control.

%package devel
Summary:        Headers for developing with arb
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       flint-devel%{?_isa}
Requires:       gmp-devel%{?_isa}
Requires:       mpfr-devel%{?_isa}

%description devel
Header files and library links for developing with arb.

%package doc
Summary:        Documentation for arb
BuildArch:      noarch
Provides:       bundled(jquery)

%description doc
Documentation for developers using the arb library.

%prep
%setup -q

# Avoid symbol collisions with flint and let optflags specify the abi flag
sed -i '/CONFIG_BLAS/d;s/WANT_NTL=1/WANT_NTL=0/;/ABI_FLAG="-m.."/d' configure

# Substitute our LDFLAGS and add an soname.  This cannot be done from the
# command line.
LDFLAGS="-Wl,--as-needed -Wl,-h,libarb.so.%{majver} $RPM_LD_FLAGS"
sed -i "s|-shared|%{optflags} $LDFLAGS &|" Makefile.in

%build
# This is NOT an autoconf-generated script.  Do not use %%configure.
./configure --prefix=%{_prefix} --disable-static --with-flint=%{_prefix} \
  --with-ntl=%{_prefix} ABI=%{__isa_bits} CFLAGS="%{optflags}"
make %{?_smp_mflags} verbose
make -C doc html PAPER=letter

%install
# Install the library
mkdir -p %{buildroot}%{_libdir}
install -m 0755 -p libarb.so %{buildroot}%{_libdir}/libarb.so.%{version}
ln -s libarb.so.%{version} %{buildroot}%{_libdir}/libarb.so.%{majver}
ln -s libarb.so.%{majver} %{buildroot}%{_libdir}/libarb.so

# Install the headers
mkdir -p %{buildroot}%{_includedir}/%{name}
cp -p *.h %{buildroot}%{_includedir}/%{name}

# Remove hidden documentation build artifacts
rm -f doc/build/html/{.buildinfo,objects.inv}

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%doc README
%license gpl-2.0.txt
%{_libdir}/libarb.so.*

%files devel
%{_includedir}/%{name}/
%{_libdir}/libarb.so

%files doc
%doc doc/build/html
%license gpl-2.0.txt

%changelog
* Fri Oct 23 2015 Jerry James <loganjerry@gmail.com> - 2.7.0-2
- Build with hardening ld flags

* Fri Oct 16 2015 Jerry James <loganjerry@gmail.com> - 2.7.0-1
- Initial RPM
